"""
================
Autokill process
================

Some scripts with Threading or Subprocessing calls could ends without terminate
all the process, this script make sure you finish the current process and the
previous process generated too.
"""

import os
import logging
import atexit
import signal
from pathlib import Path


# ----------------------------------------------------------------------
def autokill_process(name: str = '') -> None:
    """Make sure you finish the current process.

    In addition to kill the current process, it will looks for the previous
    process and kill them before the start.

    Parameters
    ----------
    name
        Name used for the PID file.
    """

    pid = os.getpid()
    logging.info(f"Running with PID: {pid}")

    PID_FILE = os.path.join(Path.home(), f".openbci.{name}.pid")
    logging.info(f"PID file created in: {PID_FILE}")

    if os.path.exists(PID_FILE):
        with open(PID_FILE, 'r') as file:
            oldpid = file.read()
            if oldpid.isdigit():
                oldpid = int(oldpid)
                if oldpid != pid:
                    try:
                        os.kill(oldpid, signal.SIGKILL)
                    except:
                        pass

    with open(PID_FILE, 'w') as file:
        file.write(str(pid))

    # ----------------------------------------------------------------------
    @atexit.register
    def _() -> None:
        logging.info(f"Killing PID: {pid}")
        try:
            os.kill(-pid, signal.SIGKILL)
            if os.path.exists(PID_FILE):
                os.remove(PID_FILE)
        except:
            pass



"""
=================
Scan WiFi modules
=================
"""

import requests
from typing import Dict


# ----------------------------------------------------------------------
def scan_wifi_modules(network: str = "wlan0") -> Dict[str, str]:
    """Scan for WiFi modules.

    Explore the local network with `nmap` in search of WiFi modules, the way to
    check if a device is a WiFi module is reading the `/board` endopint, the
    `JSON` is stored and returned too.

    Parameters
    ----------
    network
        The network interface name used e.g. `wlan0`, `wlp2s0`, 'eth0'...

    Returns
    -------
    dict
        Dictionay with IPs as keys of WiFi modules on network and `/board` as
        value.
    """

    # Optional requieres are imported only inside the function
    import netifaces
    import nmap

    ip_list = {}
    local_net = netifaces.ifaddresses(network)[netifaces.AF_INET][0]["addr"]

    nm = nmap.PortScanner()
    nm.scan(hosts=f"{local_net}/24", arguments="-sn")
    hosts = nm.all_hosts()

    for host in hosts:
        try:
            response = requests.get(f"http://{host}/board", timeout=0.1)
            if response.ok:
                ip_list[host] = response.json()
        except:
            continue

    return ip_list


if __name__ == "__main__":
    print(scan_wifi_modules())



import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
   README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
version_str = open(os.path.join(
   'openbci_stream', '_version.txt'), 'r').read().strip()

with open('requirements.txt') as f:
   requirements = f.read().splitlines()

setup(
    name='openbci-stream',
    version=version_str,
    packages=['openbci_stream', 'openbci_stream.acquisition',
              'openbci_stream.daemons', 'openbci_stream.utils'],

    author='Yeison Cardona',
    author_email='yencardonaal@unal.edu.co',
    maintainer='Yeison Cardona',
    maintainer_email='yencardonaal@unal.edu.co',

    download_url='https://github.com/UN-GCPDS/openbci_stream',

    install_requires=requirements,

    scripts=[
       "cmd/openbci_cli",
       "cmd/stream_rpyc",
       "cmd/stream_eeg",
       "cmd/stream_configure_kafka.sh",
       "cmd/stream_access_point.sh",
       "cmd/stream_configure_ntpd.sh",
       "cmd/stream_install_kafka.sh",
       "cmd/stream_tlwr.sh",
    ],

    include_package_data=True,
    license='BSD-2-Clause',
    description="High level Python module for EEG/EMG/ECG acquisition and distributed streaming for OpenBCI Cyton board.",

    long_description=README,
    long_description_content_type='text/markdown',

    python_requires='>=3.8',

    classifiers=[
       'Development Status :: 4 - Beta',
       'Intended Audience :: Developers',
       'Intended Audience :: Education',
       'Intended Audience :: Healthcare Industry',
       'Intended Audience :: Science/Research',
       'License :: OSI Approved :: BSD License',
       'Programming Language :: Python :: 3.8',
       'Topic :: Scientific/Engineering',
       'Topic :: Scientific/Engineering :: Human Machine Interfaces',
       'Topic :: Scientific/Engineering :: Medical Science Apps.',
       'Topic :: Software Development :: Embedded Systems',
       'Topic :: Software Development :: Libraries',
       'Topic :: Software Development :: Libraries :: Application Frameworks',
       'Topic :: Software Development :: Libraries :: Python Modules',
       'Topic :: System :: Hardware :: Hardware Drivers',
    ],

)
